@@ -39,7 +39,7 @@ from making_with_code_cli.cli_setup import (
     InstallPoetry,
     InstallGit,
     InstallTree,
-    InstallAtom,
+    InstallVSCode,
     InstallImageMagick,
     InstallHttpie,
     InstallScipy,
@@ -113,7 +113,7 @@ def setup(ctx, yes, teacher, config, debug):
         InstallPython3(settings),
         InstallGit(settings),
         InstallTree(settings),
-        InstallAtom(settings),
+        InstallVSCode(settings),
         InstallImageMagick(settings),
         InstallHttpie(settings),
         InstallScipy(settings),
@@ -132,7 +132,8 @@ def setup(ctx, yes, teacher, config, debug):
             click.echo(error(task.description))
             if debug:
                 click.echo(debug_fmt(tb, preformatted=True))
-    ctx.invoke(update)
+    else:
+        ctx.invoke(update)
 
 def get_course_by_name(name, courses):
     for course in courses:
