@@ -33,9 +33,9 @@ WORK_DIR_PERMISSIONS = S_IRWXU | S_IXGRP | S_IXOTH
 
 class Platform(Flag):
     MAC = auto()
-    LINUX = auto()
+    DEBIAN = auto()
     WSL = auto()
-    SUPPORTED = MAC | LINUX | WSL
+    SUPPORTED = MAC | DEBIAN | WSL
     UNSUPPORTED = 0
 
     @classmethod
@@ -44,8 +44,8 @@ class Platform(Flag):
             return self.WSL
         if sys.platform.startswith("darwin"):
             return self.MAC
-        if sys.platform.startswith("linux"):
-            return self.LINUX
+        if sys.platform.startswith("linux") and Path("/etc/debian_version").exists():
+            return self.DEBIAN
         return self.UNSUPPORTED
 
 def default_work_dir():
@@ -298,6 +298,7 @@ class InstallPackage(SetupTask):
     package_name = "package"
     brew_name = "package"
     apt_name = "package"
+    cask = False
 
     def __init__(self, *args, **kwargs):
         self.description = f"Install {self.package_name}"
@@ -309,16 +310,15 @@ class InstallPackage(SetupTask):
     def run_task(self):
         platform = Platform.detect()
         click.echo(address(f"Installing {self.package_name}..."))
-        pkg = self.brew_name if (platform == Platform.MAC) else self.apt_name
-        run(f"{self.package_installer()} install {pkg}", shell=True, check=True)
-
-    def package_installer(self):
-        platform = Platform.detect()
-        if platform == Platform.LINUX:
-            return "apt"
-        if platform == Platform.MAC:
-            return "brew"
-        raise IOError(f"Platform {platform} not supported...")
+        if platform & Platform.MAC:
+            if self.cask:
+                run(f"brew install {self.brew_name}", shell=True, check=True)
+            else:
+                run(f"brew install --cask {self.brew_name}", shell=True, check=True)
+        elif platform & (Platform.DEBIAN | Platform.WSL):
+            run(f"apt install {pkg}", shell=True, check=True)
+        else:
+            raise IOError(f"Platform {platform} not supported...")
 
 class InstallPython3(InstallPackage):
     package_name = brew_name = apt_name = "python3"
@@ -333,6 +333,11 @@ class InstallAtom(InstallPackage):
     platform = Platform.MAC
     package_name = brew_name = apt_name = "atom"
 
+class InstallVSCode(InstallPackage):
+    platform = Platform.MAC
+    package_name = brew_name = "visual-studio-code"
+    cask = True
+
 class InstallGh(InstallPackage):
     package_name = brew_name = "gh"
 
