@@ -3,11 +3,15 @@ import click
 
 FW = 80
 
-def address(message, list_format=False):
+def address(message, preformatted=False, list_format=False):
     """Addresses the user (e.g. a greeting or transition to the next step).
     This may be verbose, so text is wrapped.
     """
-    if list_format:
+    if preformatted:
+        if list_format: 
+            raise ValueError("preformatted and list_format are incompatible options")
+        fmsg = message
+    elif list_format:
         fmsg = fill(message, width=FW, initial_indent='- ', subsequent_indent='  ')
     else:
         fmsg = fill(message, width=FW) + '\n'
@@ -18,6 +22,13 @@ def question(message):
     """
     return click.style(fill(message, width=FW) + '\n', fg="cyan")
 
+def debug(message, preformatted=False):
+    """Shows the user debug information"""
+    if preformatted:
+        return click.style(message, fg="gray")
+    else:
+        return click.style(fill(message, width=FW), fg="gray")
+
 def info(message, preformatted=False):
     """Shows the user information. 
     Don't use this for boilerplate; the user should have requested the information 
